"use client";
import { useState, useEffect } from "react";
import { useSearchParams } from "next/navigation";
import AdminLayout from "@/components/admin/adminLayout";
import DeveloperWaitingApproval from "@/components/admin/admin_sidebar/TotalDeveloperProperty/DeveloperWaitingApproval";
import DeveloperApprovedProperty from "@/components/admin/admin_sidebar/TotalDeveloperProperty/DeveloperApprovedProperty";
import DeveloperRejectedProperty from "@/components/admin/admin_sidebar/TotalDeveloperProperty/DeveloperRejectedProperty";
import axios from "@/services/APIservices";

export default function TotalAgentsPropertyPage() {
  const searchParams = useSearchParams();
  
  // State to store API data
  const [userDeveloperData, setUserDeveloperData] = useState([]);
  const [totalPostDetails, setTotalPostDetails] = useState(0);
  const [totalDeveloperPostDetails, setTotalDeveloperPostDetails] = useState(0);
  const [totalDeveloperUnapproval, setTotalDeveloperUnapproval] = useState(0);
  const [totalDeveloperApproval, setTotalDeveloperApproval] = useState(0);
  const [totalDeveloperRejected, setTotalDeveloperRejected] = useState(0);
  const [developerUsersData, setDeveloperUsersData] = useState([]);  
  const [rejectedUsersData, setRejectedUsersData] = useState([]);
  const [waitingUsersData, setWaitingUsersData] = useState([]);

  //const [agentUsersData, setAgentUsersData] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // Mapping of view keys to components
  const viewComponents = {
    approved: DeveloperApprovedProperty,
    waiting: DeveloperWaitingApproval,
    rejected: DeveloperRejectedProperty,
  };

  // Extract view from URL or default to 'approved'
  const currentView = searchParams.get("view") || "approved";

  // Dynamically select the component based on current view
  const SelectedComponent = viewComponents[currentView] || DeveloperApprovedProperty;

  // Function to fetch data from the API
  const fetchUserDeveloperData = async () => {
    try {
      const response = await axios.get("/api/user-developer-data");
      if (response.data.success) {
        setUserDeveloperData(response.data.data);
        setTotalPostDetails(response.data.totalPostDetails);
        setTotalDeveloperPostDetails(response.data.totalDeveloperPostDetails);
        setTotalDeveloperUnapproval(response.data.totalDeveloperUnapproval);
        setTotalDeveloperApproval(response.data.totalDeveloperApproval);
        setTotalDeveloperRejected(response.data.totalDeveloperRejected);
        setDeveloperUsersData(response.data.developerUsersData); 
        setRejectedUsersData(response.data.rejectedUsersData);
        setWaitingUsersData(response.data.waitingUsersData);
        setError(null); // Clear any previous errors
      } else {
        setError(response.data.message || "Failed to fetch data.");
      }
    } catch (err) {
      setError(err.message || "An error occurred while fetching data.");
    } finally {
      setLoading(false); // Stop loading after fetch
    }
  };




  // New method to handle property status change
  const handlePropertyStatusChange = async (postId, statusType) => {
    try {
      let endpoint;
      if (statusType === 'waiting') {
        endpoint = `/api/user-developer-data/${postId}/waiting`;
      } else if (statusType === 'rejected') {
        endpoint = `/api/user-developer-data/${postId}/rejected`;
      } else if(statusType === 'approve') {
        endpoint = `/api/user-developer-data/${postId}/approve`;
      }

      const response = await axios.post(endpoint);
      
      if (response.data.success) {
        fetchUserDeveloperData(); // Refresh data after status change
      } else {
        setError(response.data.message || 'Failed to update status.');
      }
    } catch (err) {
      setError(err.message || 'An error occurred while updating status.');
    }
  };




  // Real-time data fetching using polling
  useEffect(() => {
    // Initial fetch
    fetchUserDeveloperData();

    // Set up polling interval
    const interval = setInterval(() => {
      fetchUserDeveloperData();
    }, 5000); // Fetch data every 5 seconds

    // Cleanup interval on component unmount
    return () => clearInterval(interval);
  }, []);

  // Show loading or error states if needed
  if (loading) {
    return (
      <AdminLayout>
        <div>Loading...</div>
      </AdminLayout>
    );
  }

  if (error) {
    return (
      <AdminLayout>
        <div>Error: {error}</div>
      </AdminLayout>
    );
  }

  return (
    <AdminLayout>
      {/* Render the selected component and pass down API data */}
      <SelectedComponent
        userDeveloperData={userDeveloperData}
        totalPostDetails={totalPostDetails} 
        totalDeveloperPostDetails={totalDeveloperPostDetails}
        totalDeveloperUnapproval={totalDeveloperUnapproval}
        totalDeveloperApproval={totalDeveloperApproval}
        totalDeveloperRejected={totalDeveloperRejected}
        developerUsersData={developerUsersData}
        rejectedUsersData={rejectedUsersData}
        waitingUsersData={waitingUsersData}
        onStatusChange={handlePropertyStatusChange} // New prop for status change handler

              />
    </AdminLayout>
  );
}